@@ -2,7 +2,6 @@ import re
 from collections import namedtuple
 from typing import List
 
-from yelp_fetcher._util import fetch_soup
 from yelp_fetcher.scraper.bs4_util import get_elements_by_classname
 from yelp_fetcher.scraper.common import get_review_ids
 
@@ -39,8 +38,3 @@ def get_user_biz_reviews(page) -> List[ScrapedReview]:
     tups = zip(biz_ids, biz_names, review_ids, review_dates)
     scraped_reviews = list(map(lambda tup: ScrapedReview(*tup), tups))
     return scraped_reviews
-
-
-get_user_biz_reviews(
-    fetch_soup(get_user_details_reviews_self_url("5prk8CtPPBHNpa6BOja2ug", 0))
-)
